@@ -4,7 +4,7 @@ Photonic::NonRetarded::FieldH
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -26,7 +26,9 @@ the components.
 
 Initializes the structure.
 
-$nr Photonic::NonRetarded::AllH is a Haydock calculator for the structure
+$nr Photonic::NonRetarded::AllH is a Haydock calculator for the
+structure, *initialized* with the flag keepStates=>1
+(Photonic::Types::NonRetarded::AllHSave, as defined in Photonic::Types).
 
 $nh is the maximum number of Haydock coefficients to use.
 
@@ -90,7 +92,7 @@ real space field in format RorI, cartesian, nx, ny,...
 =cut
 
 package Photonic::NonRetarded::FieldH;
-$Photonic::NonRetarded::FieldH::VERSION = '0.005';
+$Photonic::NonRetarded::FieldH::VERSION = '0.006';
 use namespace::autoclean;
 use PDL::Lite;
 use PDL::NiceSlice;
