@@ -1,5 +1,5 @@
 package Photonic::Types;
-$Photonic::Types::VERSION = '0.005';
+$Photonic::Types::VERSION = '0.006';
 use Moose::Util::TypeConstraints;
 #use PDL::Lite;
 #use PDL::NiceSlice;
@@ -18,8 +18,8 @@ subtype 'Photonic::Types::GeometryG0' =>
   where { $_->has_Direction0 },
   message { "You should define a direction for G=0 reciprocal vector" };
 
-subtype 'Photonic::Types::NRAllHSave' =>
-  as 'Photonic::NRAllH',
+subtype 'Photonic::Types::NonRetarded::AllHSave' =>
+  as 'Photonic::NonRetarded::AllH',
   where { $_->keepStates == 1 },
   message { "Can't calculate fields if you don't keepStates" };
 
@@ -33,7 +33,7 @@ Photonic::Types
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -63,9 +63,9 @@ Array of OddInts
 
 Photonic::Geometry with a direction for G=0 reciprocal vector
 
-=item * Photonic::Types::NRAllHSave
+=item * Photonic::Types::NonRetarded::AllHSave
 
-Photonic::NRALLH object where the keepStates flag has been
+Photonic::NonRetarded:AllH object where the keepStates flag has been
 turned on.
 
 =back
